/*
    mandelbmp - render the Mandelbrot set or Julia sets as BMP files
    Copyright (C) 2022 cas <cas@sdf.org>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/

#include "colormaps.h"
#include <math.h>


void cmap_get_rgb(int cmap, double v, int* r, int* g, int* b){
  if(v > 1)
    v = 1;
  
  if(v < 0)
    v = 0;
  
  switch(cmap){
    case 0:
      *r = NAUSEA_R(v);
      *g = NAUSEA_G(v);
      *b = NAUSEA_B(v);
      break;
    case 1:
      *r = COLORBLIND_R(v);
      *g = COLORBLIND_G(v);
      *b = COLORBLIND_B(v);
      break;
    case 2:
      *r = INVCOLORBLIND_R(v);
      *g = INVCOLORBLIND_G(v);
      *b = INVCOLORBLIND_B(v);
      break;
    case 3:
      *r = HERESY_R(v);
      *g = HERESY_G(v);
      *b = HERESY_B(v);
      break;
    case 4:
      *r = PROPHECY_R(v);
      *g = PROPHECY_G(v);
      *b = PROPHECY_B(v);
      break;
    case 5:
      *r = PARASITE_R(v);
      *g = PARASITE_G(v);
      *b = PARASITE_B(v);
      break;
    case 6:
      *r = INVADER_R(v);
      *g = INVADER_G(v);
      *b = INVADER_B(v);
      break;
    default:
      *r = NAUSEA_R(v);
      *g = NAUSEA_G(v);
      *b = NAUSEA_B(v);
  }
}
